![Build Status](https://github.com/circus-tent/circus/workflows/ci/badge.svg)
![Coverage Status](https://coveralls.io/repos/github/circus-tent/circus/badge.svg?branch=master)
![PyPI](https://img.shields.io/pypi/v/circus) 
![PyPI - Downloads](https://img.shields.io/pypi/dm/circus)
# Circus

Circus is a program that runs and watches processes and sockets.
Circus can be used as a library or through the command line.

## Links

- [Full Documentation](https://circus.readthedocs.io)
- [How to Contribute](https://circus.readthedocs.io/en/latest/contributing/)
- IRC: Freenode, channel #mozilla-circus
